@@ -252,6 +252,10 @@ class BondRisk(BaseModel):
     yield_value_basis_point: Optional[float] = None
     
 
+class BondRisk2(BondRisk):
+    value: Optional[float] = None
+    value_after_shift: Optional[float] = None
+
 class CashFlow(BaseModel):
     date: str 
     amount: float
